classdef ProcessingConfig < handle
  % ProcessingConfig
  %   Processing that can be done
  %
  % Methods:
  %   write - Write processing config to disk
  %   getGpu - Get whether processing on the gpu is enabled
  %   setGpu - Set whether processing on the gpu is enabled
  %   getCalibrationEnabled - Get whether the calibration is applied
  %   setCalibrationEnabled - Set whether the calibration is applied
  %   getPhaseUnwrappingEnabled - Get whether phase unwrapping is enabled
  %   setPhaseUnwrappingEnabled - Set whether phase unwrapping is enabled
  %   getPhaseUnwrappingMaxOffset - Get The maximum distance between ideal
  %                                 location and actual
  %   setPhaseUnwrappingMaxOffset - Set The maximum distance between ideal
  %                                 location and actual
  %   getMpiDetectEnabled - Get wether mpi detect is enabled
  %   setMpiDetectEnabled - Set wether mpi detect is enabled
  %   getMpiDetectAratio - Get The amplitude ratio value
  %   setMpiDetectAratio - Set The amplitude ratio value
  %   getMpiDetectPhiDiff - Get the phase difference ratio
  %   setMpiDetectPhiDiff - Set the phase difference ratio
  %   getMixedPixelEnabled - Get wether mixed pixel is enabled
  %   setMixedPixelEnabled - Set wether mixed pixel is enabled
  %   getMixedPixelLutFile - Get location of the mixed pixel look up table file
  %   setMixedPixelLutFile - Set location of the mixed pixel look up table file
  %   getMixedPixelAmpMin - Get minimum amplitude that pixel needs to have to
  %                         apply mixed pixel to it
  %   setMixedPixelAmpMin - Set minimum amplitude that pixel needs to have to
  %                         apply mixed pixel to it
  %   getMixedPixelSortMode - Get what output is selected
  %   setMixedPixelSortMode - Set what output is selected
  %   getMixedPixelAratio - Get the amplitude ratio for detecting MPI
  %   setMixedPixelAratio - Set the amplitude ratio for detecting MPI
  %   getMixedPixelPhiDiff - Get the phase difference for detecting MPI
  %   setMixedPixelPhiDiff - Set the phase difference for detecting MPI
  %   getMixedPixelAggressorThreshold - Get the threshold to classify a pixel as
  %                                     an aggressor
  %   setMixedPixelAggressorThreshold - Set the threshold to classify a pixel as
  %                                     an aggressor
  %   getMixedPixelMinAggressorSize - Get the minimum amount of bright pixels
  %                                   before a bright spot is classified as an
  %                                   aggressor
  %   setMixedPixelMinAggressorSize - Set the minimum amount of bright pixels
  %                                   before a bright spot is classified as an
  %                                   aggressor
  %   getMixedPixelMaxError3f - Get the maximum error when using three
  %                             modulation frequencies
  %   setMixedPixelMaxError3f - Set the maximum error when using three
  %                             modulation frequencies
  %   getMixedPixelAdaptiveAmpMax - Get the maximum amplitude for adaptive
  %                                 sorting
  %   setMixedPixelAdaptiveAmpMax - Set the maximum amplitude for adaptive
  %                                 sorting
  %   getMixedPixelAdaptiveAmpMin - Get the minimum amplitude for adaptive
  %                                 sorting
  %   setMixedPixelAdaptiveAmpMin - Set the minimum amplitude for adaptive
  %                                 sorting
  %   getMixedPixelAratioMin - Get the minimum return amplitude ratio for
  %                            adaptive sorting
  %   setMixedPixelAratioMin - Set the minimum return amplitude ratio for
  %                            adaptive sorting
  %   getMixedPixelAggressorPhiOffset - Get The maximum phase difference before
  %                                     a return is not classified as aggressor
  %   setMixedPixelAggressorPhiOffset - Set The maximum phase difference before
  %                                     a return is not classified as aggressor
  %   getHdrEnabled - Get whether hdr is enabled. High dynamic range allows you
  %                   to separate depth with high intensity difference. This is
  %                   mostly useful when the sensor is being saturated.
  %   setHdrEnabled - Set whether hdr is enabled. High dynamic range allows you
  %                   to separate depth with high intensity difference. This is
  %                   mostly useful when the sensor is being saturated.
  %   getAverageEnabled - Get whether averaging is enabled. The average process
  %                       allows you to average multiple frames together at the
  %                       cost of frame rate
  %   setAverageEnabled - Set whether averaging is enabled. The average process
  %                       allows you to average multiple frames together at the
  %                       cost of frame rate
  %   getAverageNframes - Get the number of frames to average together
  %   setAverageNframes - Set the number of frames to average together
  %   getTemporalEnabled - Get whether the temporal filter is enabled. The
  %                        temporal filter is a running average as long as the
  %                        values are within sigma standard deviations of each
  %                        other
  %   setTemporalEnabled - Set whether the temporal filter is enabled. The
  %                        temporal filter is a running average as long as the
  %                        values are within sigma standard deviations of each
  %                        other
  %   getTemporalSigma - Get the number of standard deviations before resetting
  %                      the running average
  %   setTemporalSigma - Set the number of standard deviations before resetting
  %                      the running average
  %   getTemporalNframes - Get the maximum number of frames to average together
  %   setTemporalNframes - Set the maximum number of frames to average together
  %   getGaussianEnabled - Get whether the gaussian blur is enabled. This is a
  %                        standard gaussian blur applied over the depth image
  %   setGaussianEnabled - Set whether the gaussian blur is enabled. This is a
  %                        standard gaussian blur applied over the depth image
  %   getGaussianSize - Get the gaussian region size
  %   setGaussianSize - Set the gaussian region size
  %   getGaussianSigma - Get the gaussian sigma
  %   setGaussianSigma - Set the gaussian sigma
  %   getMedianEnabled - Get whether the median filter is enabled. This is a
  %                      standard median filter applied over the depth image
  %   setMedianEnabled - Set whether the median filter is enabled. This is a
  %                      standard median filter applied over the depth image
  %   getMedianSize - Get the median region size
  %   setMedianSize - Set the median region size
  %   getBilateralEnabled - Get whether the bilateral filter is enabled. This
  %                         filter averages the current pixel with neighboring
  %                         ones if they're within the specified standard
  %                         deviation
  %   setBilateralEnabled - Set whether the bilateral filter is enabled. This
  %                         filter averages the current pixel with neighboring
  %                         ones if they're within the specified standard
  %                         deviation
  %   getBilateralSize - Get the bilateral region size
  %   setBilateralSize - Set the bilateral region size
  %   getBilateralSigma - Get the bilateral standard deviation
  %   setBilateralSigma - Set the bilateral standard deviation
  %   getLocalMeansEnabled - Get Whether the local means filter is enabled.
  %   setLocalMeansEnabled - Set Whether the local means filter is enabled.
  %   getLocalMeansSize - Get The local means region size
  %   setLocalMeansSize - Set The local means region size
  %   getLocalMeansSigma - Get The local means standard deviation for how close
  %                        values are
  %   setLocalMeansSigma - Set The local means standard deviation for how close
  %                        values are
  %   getFlyingEnabled - Get whether flying pixel filter is enabled. The flying
  %                      pixel filters out pixels when more than x edges are
  %                      farther than x size away
  %   setFlyingEnabled - Set whether flying pixel filter is enabled. The flying
  %                      pixel filters out pixels when more than x edges are
  %                      farther than x size away
  %   getFlyingShape - Get the shape of which surrounding pixels are checked
  %   setFlyingShape - Set the shape of which surrounding pixels are checked
  %   getFlyingDistance - Get the maximum distance allowed between surrounding
  %                       pixels
  %   setFlyingDistance - Set the maximum distance allowed between surrounding
  %                       pixels
  %   getFlyingEdges - Get the number of edges allowed to be larger than maximum
  %                    distance
  %   setFlyingEdges - Set the number of edges allowed to be larger than maximum
  %                    distance
  %   getAmpThresholdEnabled - Get whether the amplitude threshold filter is
  %                            enabled. This filter filters out pixels outside
  %                            of the specified values
  %   setAmpThresholdEnabled - Set whether the amplitude threshold filter is
  %                            enabled. This filter filters out pixels outside
  %                            of the specified values
  %   getAmpThresholdMin - Get the minimum amplitude allowed
  %   setAmpThresholdMin - Set the minimum amplitude allowed
  %   getAmpThresholdMax - Get the maximum amplitude allowed
  %   setAmpThresholdMax - Set the maximum amplitude allowed
  %   getDistThresholdEnabled - Get whether the distance threshold filter is
  %                             enabled. This filter filters out pixels outside
  %                             of the specified values
  %   setDistThresholdEnabled - Set whether the distance threshold filter is
  %                             enabled. This filter filters out pixels outside
  %                             of the specified values
  %   getDistThresholdMin - Get the minimum distance allowed
  %   setDistThresholdMin - Set the minimum distance allowed
  %   getDistThresholdMax - Get the maximum distance allowed
  %   setDistThresholdMax - Set the maximum distance allowed
  %   getAmpDotSegmentEnabled - Get whether the amplitude dot segmentation
  %                             filter is enabled. This filter is designed to
  %                             filter out everything but the dots in cameras
  %                             with dot illumination. It has also proved
  %                             effective at removing shadowing effects in kea
  %   setAmpDotSegmentEnabled - Set whether the amplitude dot segmentation
  %                             filter is enabled. This filter is designed to
  %                             filter out everything but the dots in cameras
  %                             with dot illumination. It has also proved
  %                             effective at removing shadowing effects in kea
  %   getAmpDotSegmentThreshold - Get the minimum corrected amplitude that is
  %                               allowed
  %   setAmpDotSegmentThreshold - Set the minimum corrected amplitude that is
  %                               allowed
  %   getAmpDotSegmentMidpoint - Get the distance after which amplitude is
  %                              increased instead of decreased
  %   setAmpDotSegmentMidpoint - Set the distance after which amplitude is
  %                              increased instead of decreased
  %   getAmpDotSegmentMaxCorrection - Get the maximum amount of correction that
  %                                   can be performed on the distance component
  %   setAmpDotSegmentMaxCorrection - Set the maximum amount of correction that
  %                                   can be performed on the distance component
  %   getCommonConsistencyEnabled - Get whether the common consistency filter is
  %                                 enabled
  %   setCommonConsistencyEnabled - Set whether the common consistency filter is
  %                                 enabled
  %   getCommonConsistencyThreshold - Get The maximum threshold for removing
  %                                   invalid pixels
  %   setCommonConsistencyThreshold - Set The maximum threshold for removing
  %                                   invalid pixels
  %   getCommonAmpRatioEnabled - Get whether the common amplitude ratio
  %                              threshold filter is enabled. This filter
  %                              calculates the difference between the amplitude
  %                              and ir data and you can set a certain
  %                              threshold. This is useful to get rid of pixels
  %                              that are heavily saturated with sunlight since
  %                              the difference between amplitude and total ir
  %                              light will be large.
  %   setCommonAmpRatioEnabled - Set whether the common amplitude ratio
  %                              threshold filter is enabled. This filter
  %                              calculates the difference between the amplitude
  %                              and ir data and you can set a certain
  %                              threshold. This is useful to get rid of pixels
  %                              that are heavily saturated with sunlight since
  %                              the difference between amplitude and total ir
  %                              light will be large.
  %   getCommonAmpRatioThreshold - Get the maximum allowed ratio
  %   setCommonAmpRatioThreshold - Set the maximum allowed ratio
  %   getMorphErodeEnabled - Get whether the morph erode filter is enabled. The
  %                          morph erode filter removes pixels that have no
  %                          neighboring (correct) pixels.
  %   setMorphErodeEnabled - Set whether the morph erode filter is enabled. The
  %                          morph erode filter removes pixels that have no
  %                          neighboring (correct) pixels.
  %   getMorphErodeShape - Get the shape of the neighboring pixels.
  %   setMorphErodeShape - Set the shape of the neighboring pixels.
  %   getDotMaskEnabled - Get whether the dot mask is enabled. It is enabled by
  %                       default, but is only applied when a dot mask is
  %                       avaliable in the calibration file.
  %   setDotMaskEnabled - Set whether the dot mask is enabled. It is enabled by
  %                       default, but is only applied when a dot mask is
  %                       avaliable in the calibration file.
  %   getRadialScale - Get how much to scale the radial value by
  %   setRadialScale - Set how much to scale the radial value by
  %   getRadialAdd - Get how much to add to the radial value
  %   setRadialAdd - Set how much to add to the radial value
  %   getIntensityScale - Get how much to scale the intensity value by
  %   setIntensityScale - Set how much to scale the intensity value by
  %   getIntensityAdd - Get how much to add to the intensity value
  %   setIntensityAdd - Set how much to add to the intensity value
  %   getCharAdd - Get the characterization addition component. The
  %                characterization function computes the sigma for the temporal
  %                and bilateral filter
  %   setCharAdd - Set the characterization addition component. The
  %                characterization function computes the sigma for the temporal
  %                and bilateral filter
  %   getCharMult - Get the characterization multiplication component. The
  %                 characterization function computes the sigma for the
  %                 temporal and bilateral filter
  %   setCharMult - Set the characterization multiplication component. The
  %                 characterization function computes the sigma for the
  %                 temporal and bilateral filter
  %   getDotDetectionEnabled - Get whether dot detection is enabled. Dot
  %                            detection removes false dots that show up due to
  %                            lens flare or other kinds of scattering. The dot
  %                            detection traces the contours of the dots and
  %                            compares amplitude dots with z dots, to make a
  %                            decision whether the dot is a valid dot.
  %   setDotDetectionEnabled - Set whether dot detection is enabled. Dot
  %                            detection removes false dots that show up due to
  %                            lens flare or other kinds of scattering. The dot
  %                            detection traces the contours of the dots and
  %                            compares amplitude dots with z dots, to make a
  %                            decision whether the dot is a valid dot.
  %   getDotDetectionCoefficientThreshold - Get threshold for the minimum
  %                                         coefficient of variance the
  %                                         amplitude can have without
  %                                         discarding the dot.
  %   setDotDetectionCoefficientThreshold - Set threshold for the minimum
  %                                         coefficient of variance the
  %                                         amplitude can have without
  %                                         discarding the dot.
  %   getDotDetectionNrows - Get the amount of rows to have, this only affects
  %                          the compressed z.
  %   setDotDetectionNrows - Set the amount of rows to have, this only affects
  %                          the compressed z.
  %   getBinningEnabled - Get whether software binning is enabled
  %   setBinningEnabled - Set whether software binning is enabled
  %   getBinningSize - Get the size of the area to bin, 2 would bin a 2x2 area
  %   setBinningSize - Set the size of the area to bin, 2 would bin a 2x2 area
  %   getBinningMode - Get the binning mode to use
  %   setBinningMode - Set the binning mode to use
  %   getBinningSigma - Get The maximum standard deviation to use, only used in
  %                     the smart binning mode
  %   setBinningSigma - Set The maximum standard deviation to use, only used in
  %                     the smart binning mode
  %   getXyzDimension - Get the dimension of the xyz output
  %   setXyzDimension - Set the dimension of the xyz output
  %   getRigidTransformationEnabled - Get whether rigid transformation is
  %                                   enabled
  %   setRigidTransformationEnabled - Set whether rigid transformation is
  %                                   enabled
  %   getRigidTransformationMatrix - Get the rigid transformation 4x4 matrix
  %   setRigidTransformationMatrix - Set the rigid transformation 4x4 matrix
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = ProcessingConfig(varargin)
      % ProcessingConfig
      %   Construct new processing_config class
      %
      % ----------
      %
      %   Create default processing config
      %
      % ----------
      %
      %   Load processing config from disk
      %
      % Inputs:
      %   1 - string - Location of processing config
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      elseif nargin == 1 && (isStringScalar(varargin{1}) || ischar(varargin{1}))
        obj.mPtr = tof.mex('tof_processing_config_new_from_disk', varargin{1});
      elseif nargin == 0 && (isStringScalar(varargin{1}) || ischar(varargin{1}))
        obj.mPtr = tof.mex('tof_processing_config_new_from_disk', );
      else
        obj.mPtr = tof.mex('tof_processing_config_new_default');
      end
    end


    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_processing_config_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function write(obj, file_location)
      % write
      %   Write processing config to disk
      %
      % Inputs:
      %   file_location - string - Location where to save the processing config
      %

      tof.mex('tof_processing_config_write', obj.mPtr, file_location);
    end

    function ret_val = getGpu(obj)
      % getGpu
      %   Get whether processing on the gpu is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_gpu', obj.mPtr);
    end

    function setGpu(obj, gpu)
      % setGpu
      %   Set whether processing on the gpu is enabled
      %
      % Inputs:
      %   gpu - logical - Enabled
      %

      tof.mex('tof_processing_config_set_gpu', obj.mPtr, gpu);
    end

    function ret_val = getCalibrationEnabled(obj)
      % getCalibrationEnabled
      %   Get whether the calibration is applied
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_calibration_enabled', obj.mPtr);
    end

    function setCalibrationEnabled(obj, enabled)
      % setCalibrationEnabled
      %   Set whether the calibration is applied
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_calibration_enabled', obj.mPtr, enabled);
    end

    function ret_val = getPhaseUnwrappingEnabled(obj)
      % getPhaseUnwrappingEnabled
      %   Get whether phase unwrapping is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_phase_unwrapping_enabled', obj.mPtr);
    end

    function setPhaseUnwrappingEnabled(obj, enabled)
      % setPhaseUnwrappingEnabled
      %   Set whether phase unwrapping is enabled
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_phase_unwrapping_enabled', obj.mPtr, enabled);
    end

    function ret_val = getPhaseUnwrappingMaxOffset(obj)
      % getPhaseUnwrappingMaxOffset
      %   Get The maximum distance between ideal location and actual
      %
      % Output:
      %   ret_val - numeric - Max offset, range [0, 1]
      %

      ret_val = tof.mex('tof_processing_config_get_phase_unwrapping_max_offset', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setPhaseUnwrappingMaxOffset(obj, max_offset)
      % setPhaseUnwrappingMaxOffset
      %   Set The maximum distance between ideal location and actual
      %
      % Inputs:
      %   max_offset - numeric - Max offset, range [0, 1]
      %

      tof.mex('tof_processing_config_set_phase_unwrapping_max_offset', obj.mPtr, max_offset);
    end

    function ret_val = getMpiDetectEnabled(obj)
      % getMpiDetectEnabled
      %   Get wether mpi detect is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_mpi_detect_enabled', obj.mPtr);
    end

    function setMpiDetectEnabled(obj, enabled)
      % setMpiDetectEnabled
      %   Set wether mpi detect is enabled
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_mpi_detect_enabled', obj.mPtr, enabled);
    end

    function ret_val = getMpiDetectAratio(obj)
      % getMpiDetectAratio
      %   Get The amplitude ratio value
      %
      % Output:
      %   ret_val - numeric - The maximum ratio
      %

      ret_val = tof.mex('tof_processing_config_get_mpi_detect_aratio', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMpiDetectAratio(obj, aratio)
      % setMpiDetectAratio
      %   Set The amplitude ratio value
      %
      % Inputs:
      %   aratio - numeric - The maximum ratio
      %

      tof.mex('tof_processing_config_set_mpi_detect_aratio', obj.mPtr, aratio);
    end

    function ret_val = getMpiDetectPhiDiff(obj)
      % getMpiDetectPhiDiff
      %   Get the phase difference ratio
      %
      % Output:
      %   ret_val - numeric - The maximum phase difference
      %

      ret_val = tof.mex('tof_processing_config_get_mpi_detect_phi_diff', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMpiDetectPhiDiff(obj, phi_diff)
      % setMpiDetectPhiDiff
      %   Set the phase difference ratio
      %
      % Inputs:
      %   phi_diff - numeric - The maximum phase difference
      %

      tof.mex('tof_processing_config_set_mpi_detect_phi_diff', obj.mPtr, phi_diff);
    end

    function ret_val = getMixedPixelEnabled(obj)
      % getMixedPixelEnabled
      %   Get wether mixed pixel is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_enabled', obj.mPtr);
    end

    function setMixedPixelEnabled(obj, enabled)
      % setMixedPixelEnabled
      %   Set wether mixed pixel is enabled
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_mixed_pixel_enabled', obj.mPtr, enabled);
    end

    function ret_val = getMixedPixelLutFile(obj)
      % getMixedPixelLutFile
      %   Get location of the mixed pixel look up table file
      %
      % Output:
      %   ret_val - string - File location
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_lut_file', obj.mPtr);
    end

    function setMixedPixelLutFile(obj, file_location)
      % setMixedPixelLutFile
      %   Set location of the mixed pixel look up table file
      %
      % Inputs:
      %   file_location - string - File location
      %

      tof.mex('tof_processing_config_set_mixed_pixel_lut_file', obj.mPtr, file_location);
    end

    function ret_val = getMixedPixelAmpMin(obj)
      % getMixedPixelAmpMin
      %   Get minimum amplitude that pixel needs to have to apply mixed pixel to
      %   it
      %
      % Output:
      %   ret_val - numeric - Minimum amplitude
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_amp_min', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAmpMin(obj, amp_min)
      % setMixedPixelAmpMin
      %   Set minimum amplitude that pixel needs to have to apply mixed pixel to
      %   it
      %
      % Inputs:
      %   amp_min - numeric - Minimum amplitude
      %

      tof.mex('tof_processing_config_set_mixed_pixel_amp_min', obj.mPtr, amp_min);
    end

    function ret_val = getMixedPixelSortMode(obj)
      % getMixedPixelSortMode
      %   Get what output is selected
      %
      % Output:
      %   ret_val - MpSortMode - Sort mode
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_sort_mode', obj.mPtr);
    end

    function setMixedPixelSortMode(obj, sort_mode)
      % setMixedPixelSortMode
      %   Set what output is selected
      %
      % Inputs:
      %   sort_mode - MpSortMode - Sort mode
      %

      tof.mex('tof_processing_config_set_mixed_pixel_sort_mode', obj.mPtr, uint32(sort_mode));
    end

    function ret_val = getMixedPixelAratio(obj)
      % getMixedPixelAratio
      %   Get the amplitude ratio for detecting MPI
      %
      % Output:
      %   ret_val - numeric - Amplitude ratio
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_aratio', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAratio(obj, aratio)
      % setMixedPixelAratio
      %   Set the amplitude ratio for detecting MPI
      %
      % Inputs:
      %   aratio - numeric - Amplitude ratio
      %

      tof.mex('tof_processing_config_set_mixed_pixel_aratio', obj.mPtr, aratio);
    end

    function ret_val = getMixedPixelPhiDiff(obj)
      % getMixedPixelPhiDiff
      %   Get the phase difference for detecting MPI
      %
      % Output:
      %   ret_val - numeric - Phase difference
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_phi_diff', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelPhiDiff(obj, phi_diff)
      % setMixedPixelPhiDiff
      %   Set the phase difference for detecting MPI
      %
      % Inputs:
      %   phi_diff - numeric - Phase difference
      %

      tof.mex('tof_processing_config_set_mixed_pixel_phi_diff', obj.mPtr, phi_diff);
    end

    function ret_val = getMixedPixelAggressorThreshold(obj)
      % getMixedPixelAggressorThreshold
      %   Get the threshold to classify a pixel as an aggressor
      %
      % Output:
      %   ret_val - numeric - Aggressor threshold
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_aggressor_threshold', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAggressorThreshold(obj, threshold)
      % setMixedPixelAggressorThreshold
      %   Set the threshold to classify a pixel as an aggressor
      %
      % Inputs:
      %   threshold - numeric - Aggressor threshold
      %

      tof.mex('tof_processing_config_set_mixed_pixel_aggressor_threshold', obj.mPtr, threshold);
    end

    function ret_val = getMixedPixelMinAggressorSize(obj)
      % getMixedPixelMinAggressorSize
      %   Get the minimum amount of bright pixels before a bright spot is
      %   classified as an aggressor
      %
      % Output:
      %   ret_val - numeric - Minimum aggressor size
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_min_aggressor_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelMinAggressorSize(obj, size)
      % setMixedPixelMinAggressorSize
      %   Set the minimum amount of bright pixels before a bright spot is
      %   classified as an aggressor
      %
      % Inputs:
      %   size - numeric - Minimum aggressor size
      %

      tof.mex('tof_processing_config_set_mixed_pixel_min_aggressor_size', obj.mPtr, size);
    end

    function ret_val = getMixedPixelMaxError3f(obj)
      % getMixedPixelMaxError3f
      %   Get the maximum error when using three modulation frequencies
      %
      % Output:
      %   ret_val - numeric - The error
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_max_error_3f', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelMaxError3f(obj, max_error_3f)
      % setMixedPixelMaxError3f
      %   Set the maximum error when using three modulation frequencies
      %
      % Inputs:
      %   max_error_3f - numeric - The error
      %

      tof.mex('tof_processing_config_set_mixed_pixel_max_error_3f', obj.mPtr, max_error_3f);
    end

    function ret_val = getMixedPixelAdaptiveAmpMax(obj)
      % getMixedPixelAdaptiveAmpMax
      %   Get the maximum amplitude for adaptive sorting
      %
      % Output:
      %   ret_val - numeric - Maximum amplitude
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_adaptive_amp_max', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAdaptiveAmpMax(obj, adaptive_amp_max)
      % setMixedPixelAdaptiveAmpMax
      %   Set the maximum amplitude for adaptive sorting
      %
      % Inputs:
      %   adaptive_amp_max - numeric - Maximum amplitude
      %

      tof.mex('tof_processing_config_set_mixed_pixel_adaptive_amp_max', obj.mPtr, adaptive_amp_max);
    end

    function ret_val = getMixedPixelAdaptiveAmpMin(obj)
      % getMixedPixelAdaptiveAmpMin
      %   Get the minimum amplitude for adaptive sorting
      %
      % Output:
      %   ret_val - numeric - Minimum amplitude
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_adaptive_amp_min', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAdaptiveAmpMin(obj, adaptive_amp_min)
      % setMixedPixelAdaptiveAmpMin
      %   Set the minimum amplitude for adaptive sorting
      %
      % Inputs:
      %   adaptive_amp_min - numeric - Minimum amplitude
      %

      tof.mex('tof_processing_config_set_mixed_pixel_adaptive_amp_min', obj.mPtr, adaptive_amp_min);
    end

    function ret_val = getMixedPixelAratioMin(obj)
      % getMixedPixelAratioMin
      %   Get the minimum return amplitude ratio for adaptive sorting
      %
      % Output:
      %   ret_val - numeric - Minimum return ratio
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_aratio_min', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAratioMin(obj, aratio_min)
      % setMixedPixelAratioMin
      %   Set the minimum return amplitude ratio for adaptive sorting
      %
      % Inputs:
      %   aratio_min - numeric - Minimum return ratio
      %

      tof.mex('tof_processing_config_set_mixed_pixel_aratio_min', obj.mPtr, aratio_min);
    end

    function ret_val = getMixedPixelAggressorPhiOffset(obj)
      % getMixedPixelAggressorPhiOffset
      %   Get The maximum phase difference before a return is not classified as
      %   aggressor
      %
      % Output:
      %   ret_val - numeric - Phase offset before not a aggressor return
      %

      ret_val = tof.mex('tof_processing_config_get_mixed_pixel_aggressor_phi_offset', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMixedPixelAggressorPhiOffset(obj, aggressor_phi_offset)
      % setMixedPixelAggressorPhiOffset
      %   Set The maximum phase difference before a return is not classified as
      %   aggressor
      %
      % Inputs:
      %   aggressor_phi_offset - numeric - Phase offset before not a aggressor
      %                                    return
      %

      tof.mex('tof_processing_config_set_mixed_pixel_aggressor_phi_offset', obj.mPtr, aggressor_phi_offset);
    end

    function ret_val = getHdrEnabled(obj)
      % getHdrEnabled
      %   Get whether hdr is enabled. High dynamic range allows you to separate
      %   depth with high intensity difference. This is mostly useful when the
      %   sensor is being saturated.
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_hdr_enabled', obj.mPtr);
    end

    function setHdrEnabled(obj, enabled)
      % setHdrEnabled
      %   Set whether hdr is enabled. High dynamic range allows you to separate
      %   depth with high intensity difference. This is mostly useful when the
      %   sensor is being saturated.
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_hdr_enabled', obj.mPtr, enabled);
    end

    function ret_val = getAverageEnabled(obj)
      % getAverageEnabled
      %   Get whether averaging is enabled. The average process allows you to
      %   average multiple frames together at the cost of frame rate
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_average_enabled', obj.mPtr);
    end

    function setAverageEnabled(obj, enabled)
      % setAverageEnabled
      %   Set whether averaging is enabled. The average process allows you to
      %   average multiple frames together at the cost of frame rate
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_average_enabled', obj.mPtr, enabled);
    end

    function ret_val = getAverageNframes(obj)
      % getAverageNframes
      %   Get the number of frames to average together
      %
      % Output:
      %   ret_val - numeric - Number of frames
      %

      ret_val = tof.mex('tof_processing_config_get_average_nframes', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setAverageNframes(obj, nframes)
      % setAverageNframes
      %   Set the number of frames to average together
      %
      % Inputs:
      %   nframes - numeric - Number of frames
      %

      tof.mex('tof_processing_config_set_average_nframes', obj.mPtr, nframes);
    end

    function ret_val = getTemporalEnabled(obj)
      % getTemporalEnabled
      %   Get whether the temporal filter is enabled. The temporal filter is a
      %   running average as long as the values are within sigma standard
      %   deviations of each other
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_temporal_enabled', obj.mPtr);
    end

    function setTemporalEnabled(obj, enabled)
      % setTemporalEnabled
      %   Set whether the temporal filter is enabled. The temporal filter is a
      %   running average as long as the values are within sigma standard
      %   deviations of each other
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_temporal_enabled', obj.mPtr, enabled);
    end

    function ret_val = getTemporalSigma(obj)
      % getTemporalSigma
      %   Get the number of standard deviations before resetting the running
      %   average
      %
      % Output:
      %   ret_val - numeric - The standard deviation
      %

      ret_val = tof.mex('tof_processing_config_get_temporal_sigma', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setTemporalSigma(obj, sigma)
      % setTemporalSigma
      %   Set the number of standard deviations before resetting the running
      %   average
      %
      % Inputs:
      %   sigma - numeric - The standard deviation
      %

      tof.mex('tof_processing_config_set_temporal_sigma', obj.mPtr, sigma);
    end

    function ret_val = getTemporalNframes(obj)
      % getTemporalNframes
      %   Get the maximum number of frames to average together
      %
      % Output:
      %   ret_val - numeric - Number of frames
      %

      ret_val = tof.mex('tof_processing_config_get_temporal_nframes', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setTemporalNframes(obj, nframes)
      % setTemporalNframes
      %   Set the maximum number of frames to average together
      %
      % Inputs:
      %   nframes - numeric - Number of frames
      %

      tof.mex('tof_processing_config_set_temporal_nframes', obj.mPtr, nframes);
    end

    function ret_val = getGaussianEnabled(obj)
      % getGaussianEnabled
      %   Get whether the gaussian blur is enabled. This is a standard gaussian
      %   blur applied over the depth image
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_gaussian_enabled', obj.mPtr);
    end

    function setGaussianEnabled(obj, enabled)
      % setGaussianEnabled
      %   Set whether the gaussian blur is enabled. This is a standard gaussian
      %   blur applied over the depth image
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_gaussian_enabled', obj.mPtr, enabled);
    end

    function ret_val = getGaussianSize(obj)
      % getGaussianSize
      %   Get the gaussian region size
      %
      % Output:
      %   ret_val - numeric - Region size, 3x3 and 5x5 are supported
      %

      ret_val = tof.mex('tof_processing_config_get_gaussian_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setGaussianSize(obj, size)
      % setGaussianSize
      %   Set the gaussian region size
      %
      % Inputs:
      %   size - numeric - Region size, 3x3 and 5x5 are supported
      %

      tof.mex('tof_processing_config_set_gaussian_size', obj.mPtr, size);
    end

    function ret_val = getGaussianSigma(obj)
      % getGaussianSigma
      %   Get the gaussian sigma
      %
      % Output:
      %   ret_val - numeric - The standard deviation
      %

      ret_val = tof.mex('tof_processing_config_get_gaussian_sigma', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setGaussianSigma(obj, sigma)
      % setGaussianSigma
      %   Set the gaussian sigma
      %
      % Inputs:
      %   sigma - numeric - The standard deviation
      %

      tof.mex('tof_processing_config_set_gaussian_sigma', obj.mPtr, sigma);
    end

    function ret_val = getMedianEnabled(obj)
      % getMedianEnabled
      %   Get whether the median filter is enabled. This is a standard median
      %   filter applied over the depth image
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_median_enabled', obj.mPtr);
    end

    function setMedianEnabled(obj, enabled)
      % setMedianEnabled
      %   Set whether the median filter is enabled. This is a standard median
      %   filter applied over the depth image
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_median_enabled', obj.mPtr, enabled);
    end

    function ret_val = getMedianSize(obj)
      % getMedianSize
      %   Get the median region size
      %
      % Output:
      %   ret_val - numeric - Region size, 3x3 and 5x5 are supported
      %

      ret_val = tof.mex('tof_processing_config_get_median_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setMedianSize(obj, size)
      % setMedianSize
      %   Set the median region size
      %
      % Inputs:
      %   size - numeric - Region size, 3x3 and 5x5 are supported
      %

      tof.mex('tof_processing_config_set_median_size', obj.mPtr, size);
    end

    function ret_val = getBilateralEnabled(obj)
      % getBilateralEnabled
      %   Get whether the bilateral filter is enabled. This filter averages the
      %   current pixel with neighboring ones if they're within the specified
      %   standard deviation
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_bilateral_enabled', obj.mPtr);
    end

    function setBilateralEnabled(obj, enabled)
      % setBilateralEnabled
      %   Set whether the bilateral filter is enabled. This filter averages the
      %   current pixel with neighboring ones if they're within the specified
      %   standard deviation
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_bilateral_enabled', obj.mPtr, enabled);
    end

    function ret_val = getBilateralSize(obj)
      % getBilateralSize
      %   Get the bilateral region size
      %
      % Output:
      %   ret_val - numeric - Region size, 3x3 and 5x5 are supported
      %

      ret_val = tof.mex('tof_processing_config_get_bilateral_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setBilateralSize(obj, size)
      % setBilateralSize
      %   Set the bilateral region size
      %
      % Inputs:
      %   size - numeric - Region size, 3x3 and 5x5 are supported
      %

      tof.mex('tof_processing_config_set_bilateral_size', obj.mPtr, size);
    end

    function ret_val = getBilateralSigma(obj)
      % getBilateralSigma
      %   Get the bilateral standard deviation
      %
      % Output:
      %   ret_val - numeric - The standard deviation
      %

      ret_val = tof.mex('tof_processing_config_get_bilateral_sigma', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setBilateralSigma(obj, sigma)
      % setBilateralSigma
      %   Set the bilateral standard deviation
      %
      % Inputs:
      %   sigma - numeric - The standard deviation
      %

      tof.mex('tof_processing_config_set_bilateral_sigma', obj.mPtr, sigma);
    end

    function ret_val = getLocalMeansEnabled(obj)
      % getLocalMeansEnabled
      %   Get Whether the local means filter is enabled.
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_local_means_enabled', obj.mPtr);
    end

    function setLocalMeansEnabled(obj, enabled)
      % setLocalMeansEnabled
      %   Set Whether the local means filter is enabled.
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_local_means_enabled', obj.mPtr, enabled);
    end

    function ret_val = getLocalMeansSize(obj)
      % getLocalMeansSize
      %   Get The local means region size
      %
      % Output:
      %   ret_val - numeric - Region size
      %

      ret_val = tof.mex('tof_processing_config_get_local_means_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setLocalMeansSize(obj, size)
      % setLocalMeansSize
      %   Set The local means region size
      %
      % Inputs:
      %   size - numeric - Region size
      %

      tof.mex('tof_processing_config_set_local_means_size', obj.mPtr, size);
    end

    function ret_val = getLocalMeansSigma(obj)
      % getLocalMeansSigma
      %   Get The local means standard deviation for how close values are
      %
      % Output:
      %   ret_val - numeric - The stand deviation
      %

      ret_val = tof.mex('tof_processing_config_get_local_means_sigma', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setLocalMeansSigma(obj, sigma)
      % setLocalMeansSigma
      %   Set The local means standard deviation for how close values are
      %
      % Inputs:
      %   sigma - numeric - The stand deviation
      %

      tof.mex('tof_processing_config_set_local_means_sigma', obj.mPtr, sigma);
    end

    function ret_val = getFlyingEnabled(obj)
      % getFlyingEnabled
      %   Get whether flying pixel filter is enabled. The flying pixel filters
      %   out pixels when more than x edges are farther than x size away
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_flying_enabled', obj.mPtr);
    end

    function setFlyingEnabled(obj, enabled)
      % setFlyingEnabled
      %   Set whether flying pixel filter is enabled. The flying pixel filters
      %   out pixels when more than x edges are farther than x size away
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_flying_enabled', obj.mPtr, enabled);
    end

    function ret_val = getFlyingShape(obj)
      % getFlyingShape
      %   Get the shape of which surrounding pixels are checked
      %
      % Output:
      %   ret_val - FlyingShape - The shape
      %

      ret_val = tof.mex('tof_processing_config_get_flying_shape', obj.mPtr);
    end

    function setFlyingShape(obj, shape)
      % setFlyingShape
      %   Set the shape of which surrounding pixels are checked
      %
      % Inputs:
      %   shape - FlyingShape - The shape
      %

      tof.mex('tof_processing_config_set_flying_shape', obj.mPtr, uint32(shape));
    end

    function ret_val = getFlyingDistance(obj)
      % getFlyingDistance
      %   Get the maximum distance allowed between surrounding pixels
      %
      % Output:
      %   ret_val - numeric - Maximum distance
      %

      ret_val = tof.mex('tof_processing_config_get_flying_distance', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setFlyingDistance(obj, distance)
      % setFlyingDistance
      %   Set the maximum distance allowed between surrounding pixels
      %
      % Inputs:
      %   distance - numeric - Maximum distance
      %

      tof.mex('tof_processing_config_set_flying_distance', obj.mPtr, distance);
    end

    function ret_val = getFlyingEdges(obj)
      % getFlyingEdges
      %   Get the number of edges allowed to be larger than maximum distance
      %
      % Output:
      %   ret_val - numeric - Maximum edges
      %

      ret_val = tof.mex('tof_processing_config_get_flying_edges', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setFlyingEdges(obj, edges)
      % setFlyingEdges
      %   Set the number of edges allowed to be larger than maximum distance
      %
      % Inputs:
      %   edges - numeric - Maximum edges
      %

      tof.mex('tof_processing_config_set_flying_edges', obj.mPtr, edges);
    end

    function ret_val = getAmpThresholdEnabled(obj)
      % getAmpThresholdEnabled
      %   Get whether the amplitude threshold filter is enabled. This filter
      %   filters out pixels outside of the specified values
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_amp_threshold_enabled', obj.mPtr);
    end

    function setAmpThresholdEnabled(obj, enabled)
      % setAmpThresholdEnabled
      %   Set whether the amplitude threshold filter is enabled. This filter
      %   filters out pixels outside of the specified values
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_amp_threshold_enabled', obj.mPtr, enabled);
    end

    function ret_val = getAmpThresholdMin(obj)
      % getAmpThresholdMin
      %   Get the minimum amplitude allowed
      %
      % Output:
      %   ret_val - numeric - Minimum value
      %

      ret_val = tof.mex('tof_processing_config_get_amp_threshold_min', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setAmpThresholdMin(obj, min)
      % setAmpThresholdMin
      %   Set the minimum amplitude allowed
      %
      % Inputs:
      %   min - numeric - Minimum value
      %

      tof.mex('tof_processing_config_set_amp_threshold_min', obj.mPtr, min);
    end

    function ret_val = getAmpThresholdMax(obj)
      % getAmpThresholdMax
      %   Get the maximum amplitude allowed
      %
      % Output:
      %   ret_val - numeric - Maximum value
      %

      ret_val = tof.mex('tof_processing_config_get_amp_threshold_max', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setAmpThresholdMax(obj, max)
      % setAmpThresholdMax
      %   Set the maximum amplitude allowed
      %
      % Inputs:
      %   max - numeric - Maximum value
      %

      tof.mex('tof_processing_config_set_amp_threshold_max', obj.mPtr, max);
    end

    function ret_val = getDistThresholdEnabled(obj)
      % getDistThresholdEnabled
      %   Get whether the distance threshold filter is enabled. This filter
      %   filters out pixels outside of the specified values
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_dist_threshold_enabled', obj.mPtr);
    end

    function setDistThresholdEnabled(obj, enabled)
      % setDistThresholdEnabled
      %   Set whether the distance threshold filter is enabled. This filter
      %   filters out pixels outside of the specified values
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_dist_threshold_enabled', obj.mPtr, enabled);
    end

    function ret_val = getDistThresholdMin(obj)
      % getDistThresholdMin
      %   Get the minimum distance allowed
      %
      % Output:
      %   ret_val - numeric - Minimum value
      %

      ret_val = tof.mex('tof_processing_config_get_dist_threshold_min', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setDistThresholdMin(obj, min)
      % setDistThresholdMin
      %   Set the minimum distance allowed
      %
      % Inputs:
      %   min - numeric - Minimum value
      %

      tof.mex('tof_processing_config_set_dist_threshold_min', obj.mPtr, min);
    end

    function ret_val = getDistThresholdMax(obj)
      % getDistThresholdMax
      %   Get the maximum distance allowed
      %
      % Output:
      %   ret_val - numeric - Maximum value
      %

      ret_val = tof.mex('tof_processing_config_get_dist_threshold_max', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setDistThresholdMax(obj, max)
      % setDistThresholdMax
      %   Set the maximum distance allowed
      %
      % Inputs:
      %   max - numeric - Maximum value
      %

      tof.mex('tof_processing_config_set_dist_threshold_max', obj.mPtr, max);
    end

    function ret_val = getRadialScale(obj)
      % getRadialScale
      %   Get how much to scale the radial value by
      %
      % Output:
      %   ret_val - numeric - Radial scale
      %

      ret_val = tof.mex('tof_processing_config_get_radial_scale', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setRadialScale(obj, scale)
      % setRadialScale
      %   Set how much to scale the radial value by
      %
      % Inputs:
      %   scale - numeric - Radial scale
      %

      tof.mex('tof_processing_config_set_radial_scale', obj.mPtr, scale);
    end

    function ret_val = getRadialAdd(obj)
      % getRadialAdd
      %   Get how much to add to the radial value
      %
      % Output:
      %   ret_val - numeric - Radial addition
      %

      ret_val = tof.mex('tof_processing_config_get_radial_add', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setRadialAdd(obj, addition)
      % setRadialAdd
      %   Set how much to add to the radial value
      %
      % Inputs:
      %   addition - numeric - Radial addition
      %

      tof.mex('tof_processing_config_set_radial_add', obj.mPtr, addition);
    end

    function ret_val = getIntensityScale(obj)
      % getIntensityScale
      %   Get how much to scale the intensity value by
      %
      % Output:
      %   ret_val - numeric - Intensity scale
      %

      ret_val = tof.mex('tof_processing_config_get_intensity_scale', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setIntensityScale(obj, scale)
      % setIntensityScale
      %   Set how much to scale the intensity value by
      %
      % Inputs:
      %   scale - numeric - Intensity scale
      %

      tof.mex('tof_processing_config_set_intensity_scale', obj.mPtr, scale);
    end

    function ret_val = getIntensityAdd(obj)
      % getIntensityAdd
      %   Get how much to add to the intensity value
      %
      % Output:
      %   ret_val - numeric - Intensity addition
      %

      ret_val = tof.mex('tof_processing_config_get_intensity_add', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setIntensityAdd(obj, addition)
      % setIntensityAdd
      %   Set how much to add to the intensity value
      %
      % Inputs:
      %   addition - numeric - Intensity addition
      %

      tof.mex('tof_processing_config_set_intensity_add', obj.mPtr, addition);
    end

    function ret_val = getCharAdd(obj)
      % getCharAdd
      %   Get the characterization addition component. The characterization
      %   function computes the sigma for the temporal and bilateral filter
      %
      % Output:
      %   ret_val - numeric - addition
      %

      ret_val = tof.mex('tof_processing_config_get_char_add', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setCharAdd(obj, addition)
      % setCharAdd
      %   Set the characterization addition component. The characterization
      %   function computes the sigma for the temporal and bilateral filter
      %
      % Inputs:
      %   addition - numeric - addition
      %

      tof.mex('tof_processing_config_set_char_add', obj.mPtr, addition);
    end

    function ret_val = getCharMult(obj)
      % getCharMult
      %   Get the characterization multiplication component. The
      %   characterization function computes the sigma for the temporal and
      %   bilateral filter
      %
      % Output:
      %   ret_val - numeric - Multiplication
      %

      ret_val = tof.mex('tof_processing_config_get_char_mult', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setCharMult(obj, multiplication)
      % setCharMult
      %   Set the characterization multiplication component. The
      %   characterization function computes the sigma for the temporal and
      %   bilateral filter
      %
      % Inputs:
      %   multiplication - numeric - Multiplication
      %

      tof.mex('tof_processing_config_set_char_mult', obj.mPtr, multiplication);
    end

    function ret_val = getBinningEnabled(obj)
      % getBinningEnabled
      %   Get whether software binning is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_binning_enabled', obj.mPtr);
    end

    function setBinningEnabled(obj, enabled)
      % setBinningEnabled
      %   Set whether software binning is enabled
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_binning_enabled', obj.mPtr, enabled);
    end

    function ret_val = getBinningSize(obj)
      % getBinningSize
      %   Get the size of the area to bin, 2 would bin a 2x2 area
      %
      % Output:
      %   ret_val - numeric - The bin size
      %

      ret_val = tof.mex('tof_processing_config_get_binning_size', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setBinningSize(obj, size)
      % setBinningSize
      %   Set the size of the area to bin, 2 would bin a 2x2 area
      %
      % Inputs:
      %   size - numeric - The bin size
      %

      tof.mex('tof_processing_config_set_binning_size', obj.mPtr, size);
    end

    function ret_val = getBinningMode(obj)
      % getBinningMode
      %   Get the binning mode to use
      %
      % Output:
      %   ret_val - BinningMode - The binning mode
      %

      ret_val = tof.mex('tof_processing_config_get_binning_mode', obj.mPtr);
    end

    function setBinningMode(obj, mode)
      % setBinningMode
      %   Set the binning mode to use
      %
      % Inputs:
      %   mode - BinningMode - The binning mode
      %

      tof.mex('tof_processing_config_set_binning_mode', obj.mPtr, uint32(mode));
    end

    function ret_val = getBinningSigma(obj)
      % getBinningSigma
      %   Get The maximum standard deviation to use, only used in the smart
      %   binning mode
      %
      % Output:
      %   ret_val - numeric - The standard deviation
      %

      ret_val = tof.mex('tof_processing_config_get_binning_sigma', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setBinningSigma(obj, sigma)
      % setBinningSigma
      %   Set The maximum standard deviation to use, only used in the smart
      %   binning mode
      %
      % Inputs:
      %   sigma - numeric - The standard deviation
      %

      tof.mex('tof_processing_config_set_binning_sigma', obj.mPtr, sigma);
    end

    function ret_val = getXyzDimension(obj)
      % getXyzDimension
      %   Get the dimension of the xyz output
      %
      % Output:
      %   ret_val - XyzDimension - The dimension
      %

      ret_val = tof.mex('tof_processing_config_get_xyz_dimension', obj.mPtr);
    end

    function setXyzDimension(obj, dimension)
      % setXyzDimension
      %   Set the dimension of the xyz output
      %
      % Inputs:
      %   dimension - XyzDimension - The dimension
      %

      tof.mex('tof_processing_config_set_xyz_dimension', obj.mPtr, uint32(dimension));
    end

    function ret_val = getRigidTransformationEnabled(obj)
      % getRigidTransformationEnabled
      %   Get whether rigid transformation is enabled
      %
      % Output:
      %   ret_val - logical - Enabled
      %

      ret_val = tof.mex('tof_processing_config_get_rigid_transformation_enabled', obj.mPtr);
    end

    function setRigidTransformationEnabled(obj, enabled)
      % setRigidTransformationEnabled
      %   Set whether rigid transformation is enabled
      %
      % Inputs:
      %   enabled - logical - Enabled
      %

      tof.mex('tof_processing_config_set_rigid_transformation_enabled', obj.mPtr, enabled);
    end

    function ret_val = getRigidTransformationMatrix(obj)
      % getRigidTransformationMatrix
      %   Get the rigid transformation 4x4 matrix
      %
      % Output:
      %   ret_val - array[numeric] - 4x4 transformation matrix
      %

      ret_val = tof.mex('tof_processing_config_get_rigid_transformation_matrix', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setRigidTransformationMatrix(obj, matrix)
      % setRigidTransformationMatrix
      %   Set the rigid transformation 4x4 matrix
      %
      % Inputs:
      %   matrix - array[numeric] - 4x4 transformation matrix
      %

      tof.mex('tof_processing_config_set_rigid_transformation_matrix', obj.mPtr, single(matrix));
    end

  end
end
